@@ -3,7 +3,7 @@ package forwarder
 import (
 	"fmt"
 
-	yaml "gopkg.in/yaml.v2"
+	yaml "sigs.k8s.io/yaml"
 
 	"github.com/ViaQ/logerr/log"
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
@@ -42,8 +42,8 @@ func Generate(clfYaml string, includeDefaultLogStore, includeLegacyForward bool)
 		Cluster: &logging.ClusterLogging{
 			Spec: logging.ClusterLoggingSpec{},
 		},
-		FnIncludeLegacyForward:  func()bool { return includeLegacyForward},
-		FnIncludeLegacySyslog:  func()bool { return includeLegacySyslog},
+		FnIncludeLegacyForward: func() bool { return includeLegacyForward },
+		FnIncludeLegacySyslog:  func() bool { return includeLegacySyslog },
 	}
 	if includeDefaultLogStore {
 		clRequest.Cluster.Spec.LogStore = &logging.LogStoreSpec{
@@ -51,6 +51,7 @@ func Generate(clfYaml string, includeDefaultLogStore, includeLegacyForward bool)
 		}
 	}
 	spec, status := clRequest.NormalizeForwarder()
+	log.V(2).Info("Normalization", "spec", spec)
 	log.V(2).Info("Normalization", "status", status)
 	tunings := &logging.ForwarderSpec{}
 
