@@ -65,6 +65,19 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			results, err := generator.generateOutputLabelBlocks(outputs, nil, forwarderSpec)
 			Expect(err).To(BeNil())
 			Expect(results[0]).To(EqualTrimLines(`<label @ONCLUSTER_ELASTICSEARCH>
+	<filter **>
+	  @type record_modifier
+	  remove_keys structured
+	</filter>
+	#flatten labels to prevent field explosion in ES    
+	<filter ** >       
+		@type record_transformer    
+		enable_ruby true    
+		<record>    
+			kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }    
+		</record>        
+		remove_keys $.kubernetes.labels    
+	</filter>
 	<match retry_oncluster_elasticsearch>
 		@type copy
 		<store>
@@ -78,10 +91,10 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
 			remove_keys viaq_index_name
-
 			client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 			client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 			ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
+
 			type_name _doc
             http_backend typhoeus
 			write_operation create
@@ -105,7 +118,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 				retry_max_interval 60s
 				retry_forever true
 				queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-				total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+				total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
 				chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 				overflow_action block
 			</buffer>
@@ -124,10 +137,10 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
 			remove_keys viaq_index_name
-
 			client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 			client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 			ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
+
 			type_name _doc
 			retry_tag retry_oncluster_elasticsearch
             http_backend typhoeus
@@ -152,7 +165,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 				retry_max_interval 60s
 				retry_forever true
 				queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-				total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+				total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
 				chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 				overflow_action block
 			</buffer>
@@ -177,6 +190,19 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			results, err := generator.generateOutputLabelBlocks(outputs, nil, forwarderSpec)
 			Expect(err).To(BeNil())
 			Expect(results[0]).To(EqualTrimLines(`<label @OTHER_ELASTICSEARCH>
+	<filter **>
+	  @type record_modifier
+	  remove_keys structured
+	</filter>
+	#flatten labels to prevent field explosion in ES
+	<filter ** >
+		@type record_transformer
+		enable_ruby true
+		<record>
+			kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
+		</record>
+		remove_keys $.kubernetes.labels
+	</filter>
 	<match retry_other_elasticsearch>
 		@type copy
 		<store>
@@ -184,7 +210,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			@id retry_other_elasticsearch
 			host es.svc.messaging.cluster.local
 			port 9654
-            verify_es_version_at_startup false
+            		verify_es_version_at_startup false
 			scheme http
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
@@ -213,7 +239,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 				retry_max_interval 60s
 				retry_forever true
 				queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-				total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+				total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
 				chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 				overflow_action block
 			</buffer>
@@ -226,7 +252,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			@id other_elasticsearch
 			host es.svc.messaging.cluster.local
 			port 9654
-            verify_es_version_at_startup false
+            		verify_es_version_at_startup false
 			scheme http
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
@@ -256,7 +282,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 				retry_max_interval 60s
 				retry_forever true
 				queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-				total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+				total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
 				chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 				overflow_action block
 			</buffer>
