@@ -58,7 +58,8 @@ var _ = Describe("Generating fluentd secure forward output store config blocks",
       <match **>
         # https://docs.fluentd.org/v1.0/articles/in_forward
         @type forward
-    		heartbeat_type none
+        heartbeat_type none
+        keepalive true
         transport tls
         tls_verify_hostname false
         tls_version 'TLSv1_2'
@@ -69,7 +70,7 @@ var _ = Describe("Generating fluentd secure forward output store config blocks",
           @type file
           path '/var/lib/fluentd/secureforward_receiver'
           queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
           chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
           flush_mode interval
           flush_interval 5s
@@ -103,7 +104,8 @@ var _ = Describe("Generating fluentd secure forward output store config blocks",
       <match **>
         # https://docs.fluentd.org/v1.0/articles/in_forward
         @type forward
-    		heartbeat_type none
+        heartbeat_type none
+        keepalive true
         transport tls
         tls_verify_hostname false
         tls_version 'TLSv1_2'
@@ -113,7 +115,7 @@ var _ = Describe("Generating fluentd secure forward output store config blocks",
           @type file
           path '/var/lib/fluentd/secureforward_receiver'
           queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
           chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
           flush_mode interval
           flush_interval 5s
@@ -144,46 +146,47 @@ var _ = Describe("Generating fluentd secure forward output store config blocks",
 			Expect(len(results)).To(Equal(1))
 			Expect(results[0]).To(EqualTrimLines(`<label @SECUREFORWARD_RECEIVER>
   <match **>
-    # https://docs.fluentd.org/v1.0/articles/in_forward
+     # https://docs.fluentd.org/v1.0/articles/in_forward
      @type forward
      heartbeat_type none
+     keepalive true
      <security>
        self_hostname "#{ENV['NODE_NAME']}"
        shared_key "my-key"
      </security>
 
-		 transport tls
-		 tls_verify_hostname false
-		 tls_version 'TLSv1_2'
+     transport tls
+     tls_verify_hostname false
+     tls_version 'TLSv1_2'
 
-		 tls_client_private_key_path "/var/run/ocp-collector/secrets/my-infra-secret/tls.key"
-		 tls_client_cert_path "/var/run/ocp-collector/secrets/my-infra-secret/tls.crt"
-		 tls_cert_path "/var/run/ocp-collector/secrets/my-infra-secret/ca-bundle.crt"
+     tls_client_private_key_path "/var/run/ocp-collector/secrets/my-infra-secret/tls.key"
+     tls_client_cert_path "/var/run/ocp-collector/secrets/my-infra-secret/tls.crt"
+     tls_cert_path "/var/run/ocp-collector/secrets/my-infra-secret/ca-bundle.crt"
 
      <buffer>
        @type file
        path '/var/lib/fluentd/secureforward_receiver'
        queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-       total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+       total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
        chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
        flush_mode interval
-	     flush_interval 5s
-	     flush_at_shutdown true
-	     flush_thread_count 2
+       flush_interval 5s
+       flush_at_shutdown true
+       flush_thread_count 2
        retry_type exponential_backoff
        retry_wait 1s
-	     retry_max_interval 60s
-	     retry_forever true
-	     # the systemd journald 0.0.8 input plugin will just throw away records if the buffer
-	     # queue limit is hit - 'block' will halt further reads and keep retrying to flush the
-	     # buffer to the remote - default is 'block' because in_tail handles that case
-	     overflow_action block
-	   </buffer>
+       retry_max_interval 60s
+       retry_forever true
+       # the systemd journald 0.0.8 input plugin will just throw away records if the buffer
+       # queue limit is hit - 'block' will halt further reads and keep retrying to flush the
+       # buffer to the remote - default is 'block' because in_tail handles that case
+       overflow_action block
+	 </buffer>
 
-		<server>
-			host es.svc.messaging.cluster.local
-			port 9654
-		</server>
+	 <server>
+	   host es.svc.messaging.cluster.local
+	   port 9654
+	 </server>
 	</match>
 </label>`))
 		})
@@ -208,12 +211,13 @@ var _ = Describe("Generating fluentd secure forward output store config blocks",
 				# https://docs.fluentd.org/v1.0/articles/in_forward
 				@type forward
 				heartbeat_type none
+				keepalive true
 
 				<buffer>
 					@type file
 					path '/var/lib/fluentd/secureforward_receiver'
 					queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-					total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+					total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
 					chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
 					flush_mode interval
 					flush_interval 5s
