@@ -105,7 +105,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             </pattern>
             <pattern>
               format regexp
-              expression /^(?<time>.+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
+              expression /^(?<time>[^\s]+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
               time_format '%Y-%m-%dT%H:%M:%S.%N%:z'
               keep_time_key true
             </pattern>
@@ -225,11 +225,6 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <label @INGRESS>
 
           ## filters
-          <filter **>
-            @type record_modifier
-            char_encoding utf-8
-          </filter>
-
           <filter journal>
             @type grep
             <exclude>
@@ -433,16 +428,6 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             alt_tags 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'
           </filter>
 
-          #flatten labels to prevent field explosion in ES
-          <filter ** >
-            @type record_transformer
-            enable_ruby true
-            <record>
-              kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
-            </record>
-            remove_keys $.kubernetes.labels
-          </filter>
-
           # Relabel specific source tags to specific intermediary labels for copy processing
           # Earlier matchers remove logs so they don't fall through to later ones.
           # A log source matcher may be null if no pipeline wants that type of log.
@@ -601,7 +586,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             </pattern>
             <pattern>
               format regexp
-              expression /^(?<time>.+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
+              expression /^(?<time>[^\s]+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
               time_format '%Y-%m-%dT%H:%M:%S.%N%:z'
               keep_time_key true
             </pattern>
@@ -721,11 +706,6 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <label @INGRESS>
 
           ## filters
-          <filter **>
-            @type record_modifier
-            char_encoding utf-8
-          </filter>
-
           <filter journal>
             @type grep
             <exclude>
@@ -928,16 +908,6 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             alt_tags 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'
           </filter>
 
-          #flatten labels to prevent field explosion in ES
-          <filter ** >
-            @type record_transformer
-            enable_ruby true
-            <record>
-              kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
-            </record>
-            remove_keys $.kubernetes.labels
-          </filter>
-
           # Relabel specific source tags to specific intermediary labels for copy processing
 					# Earlier matchers remove logs so they don't fall through to later ones.
 					# A log source matcher may be null if no pipeline wants that type of log.
@@ -1107,7 +1077,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             </pattern>
             <pattern>
               format regexp
-              expression /^(?<time>.+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
+              expression /^(?<time>[^\s]+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
               time_format '%Y-%m-%dT%H:%M:%S.%N%:z'
               keep_time_key true
             </pattern>
@@ -1227,11 +1197,6 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <label @INGRESS>
 
           ## filters
-          <filter **>
-            @type record_modifier
-            char_encoding utf-8
-          </filter>
-
           <filter journal>
             @type grep
             <exclude>
@@ -1435,16 +1400,6 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             alt_tags 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'
           </filter>
 
-          #flatten labels to prevent field explosion in ES
-          <filter ** >
-            @type record_transformer
-            enable_ruby true
-            <record>
-              kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
-            </record>
-            remove_keys $.kubernetes.labels
-          </filter>
-
           # Relabel specific source tags to specific intermediary labels for copy processing
           # Earlier matchers remove logs so they don't fall through to later ones.
           # A log source matcher may be null if no pipeline wants that type of log.
