@@ -60,6 +60,19 @@ var _ = Describe("Generating fluentd config", func() {
 		It("should provide a default buffer configuration", func() {
 			esConf := `
         <label @OTHER_ELASTICSEARCH>
+		  <filter **>
+		    @type record_modifier
+		    remove_keys structured
+		  </filter>
+		  #flatten labels to prevent field explosion in ES    
+		  <filter ** >       
+			  @type record_transformer    
+			  enable_ruby true    
+			  <record>    
+				  kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }    
+			  </record>        
+			  remove_keys $.kubernetes.labels    
+		  </filter>		
           <match retry_other_elasticsearch>
             @type copy
             <store>
@@ -96,7 +109,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -139,7 +152,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -173,6 +186,19 @@ var _ = Describe("Generating fluentd config", func() {
 		It("should provide a default buffer configuration", func() {
 			esConf := `
         <label @OTHER_ELASTICSEARCH>
+		  <filter **>
+		    @type record_modifier
+		    remove_keys structured
+		  </filter>
+		  #flatten labels to prevent field explosion in ES    
+		  <filter ** >       
+			  @type record_transformer    
+			  enable_ruby true    
+			  <record>    
+				  kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }    
+			  </record>        
+			  remove_keys $.kubernetes.labels    
+		  </filter>		  
           <match retry_other_elasticsearch>
             @type copy
             <store>
@@ -209,7 +235,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -252,7 +278,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -269,6 +295,20 @@ var _ = Describe("Generating fluentd config", func() {
 		It("should override buffer configuration for given tuning parameters", func() {
 			esConf := `
         <label @OTHER_ELASTICSEARCH>
+		<filter **>
+		  @type record_modifier
+		  remove_keys structured
+		</filter>
+		  #flatten labels to prevent field explosion in ES    
+		  <filter ** >       
+			  @type record_transformer    
+			  enable_ruby true    
+			  <record>    
+				  kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }    
+			  </record>        
+			  remove_keys $.kubernetes.labels    
+		  </filter> 		
+
           <match retry_other_elasticsearch>
             @type copy
             <store>
@@ -386,12 +426,13 @@ var _ = Describe("Generating fluentd config", func() {
             # https://docs.fluentd.org/v1.0/articles/in_forward
             @type forward
             heartbeat_type none
+            keepalive true
 
             <buffer>
             @type file
             path '/var/lib/fluentd/secureforward_receiver'
             queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-            total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+            total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
             chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
             flush_mode interval
             flush_interval 5s
@@ -427,6 +468,7 @@ var _ = Describe("Generating fluentd config", func() {
           # https://docs.fluentd.org/v1.0/articles/in_forward
           @type forward
           heartbeat_type none
+          keepalive true
 
           <buffer>
           @type file
@@ -482,10 +524,10 @@ var _ = Describe("Generating fluentd config", func() {
 			syslogConf := `
         <label @SYSLOG_RECEIVER>
           <filter **>
-          @type parse_json_field
-          json_fields  message
-          merge_json_log false
-          replace_json_log true
+			@type parse_json_field
+			json_fields  message
+			merge_json_log false
+			replace_json_log true
           </filter>
           <match **>
             @type copy
@@ -518,7 +560,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -536,10 +578,10 @@ var _ = Describe("Generating fluentd config", func() {
 			syslogConf := `
         <label @SYSLOG_RECEIVER>
           <filter **>
-          @type parse_json_field
-          json_fields  message
-          merge_json_log false
-          replace_json_log true
+			  @type parse_json_field
+			  json_fields  message
+			  merge_json_log false
+			  replace_json_log true
           </filter>
           <match **>
             @type copy
@@ -625,7 +667,7 @@ var _ = Describe("Generating fluentd config", func() {
                retry_max_interval 60s
                retry_forever true
                queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-               total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
+               total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
                chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                overflow_action block
            </buffer>
