@@ -9,8 +9,9 @@ var templateRegistry = []string{
 	inputSourceOpenShiftAuditTemplate,
 	fluentConfTemplate,
 	pipelineToOutputCopyTemplate,
-	namespaceToPipelineTemplate,
 	sourceToPipelineCopyTemplate,
+	inputSelectorToPipelineTemplate,
+	inputSelectorBlockTemplate,
 	outputLabelConfTemplate,
 	outputLabelConfNocopyTemplate,
 	outputLabelConfNoretryTemplate,
@@ -139,11 +140,6 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
 <label @INGRESS>
 
   ## filters
-  <filter **>
-    @type record_modifier
-    char_encoding utf-8
-  </filter>
-
   <filter journal>
     @type grep
     <exclude>
@@ -347,16 +343,6 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
     alt_tags 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'
   </filter>
 
-  #flatten labels to prevent field explosion in ES
-  <filter ** >
-    @type record_transformer
-    enable_ruby true
-    <record>
-      kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
-    </record>
-    remove_keys $.kubernetes.labels
-  </filter>
-
   # Relabel specific source tags to specific intermediary labels for copy processing
   # Earlier matchers remove logs so they don't fall through to later ones.
   # A log source matcher may be null if no pipeline wants that type of log.
@@ -470,7 +456,7 @@ const inputSourceContainerTemplate = `{{- define "inputSourceContainerTemplate"
     </pattern>
     <pattern>
       format regexp
-      expression /^(?<time>.+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
+      expression /^(?<time>[^\s]+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
       time_format '%Y-%m-%dT%H:%M:%S.%N%:z'
       keep_time_key true
     </pattern>
@@ -531,47 +517,11 @@ const inputSourceOpenShiftAuditTemplate = `{{- define "inputSourceOpenShiftAudit
 </source>
 {{- end}}`
 
-const namespaceToPipelineTemplate = `{{- define "namespaceToPipelineTemplate" -}}
-<label {{sourceTypelabelName .Source}}>
-  <match **>
-    @type copy
-  {{- range $index, $pipelineName := .AppAllPipelineNames }}
-    <store>
-      @type relabel
-      @label {{labelName $pipelineName}}
-    </store>
-  {{- end }}
-  {{ if .AppNamespaces }}
-    <store>
-      @type relabel
-      @label {{sourceTypelabelName .Source}}_NAMESPACE_FILTERING
-    </store>
-  {{- end }}
-  </match>
-</label>
-  {{ if .AppNamespaces }}
-<label {{sourceTypelabelName .Source}}_NAMESPACE_FILTERING>
-  {{- $pipelines := $.PipeLines -}}
-  {{- range $nsindex, $ns := .AppNamespaces }}
-  <match {{applicationTag $ns}}>
-    @type copy
-  {{- range $index, $pipelineName := (routeMapValues $pipelines $ns) }}
-    <store>
-      @type relabel
-      @label {{labelName $pipelineName}}
-    </store>
-  {{- end }}
-  </match>
-  {{- end }}
-</label>
-  {{- end }}
-{{- end}}`
-
 const sourceToPipelineCopyTemplate = `{{- define "sourceToPipelineCopyTemplate" -}}
 <label {{sourceTypelabelName .Source}}>
   <match **>
     @type copy
-{{ range $index, $pipelineLabel := .PipelineNames }}
+{{- range $index, $pipelineLabel := .PipelineNames }}
     <store>
       @type relabel
       @label {{labelName $pipelineLabel}}
@@ -581,6 +531,51 @@ const sourceToPipelineCopyTemplate = `{{- define "sourceToPipelineCopyTemplate"
 </label>
 {{- end}}`
 
+const inputSelectorToPipelineTemplate = `{{- define "inputSelectorToPipelineTemplate" -}}
+<label {{sourceTypelabelName .Source}}>
+  <match **>
+    @type label_router
+    {{- range .InputSelectors }}
+    {{ . }}
+    {{- end}}
+{{- if .PipelineNames }}
+    <route>
+      @label {{sourceTypelabelName .Source}}_ALL
+      <match>
+      </match>
+    </route>
+{{- end }}
+  </match>
+</label>
+{{ if .PipelineNames -}}
+<label {{sourceTypelabelName .Source}}_ALL>
+  <match **>
+    @type copy
+{{- range $index, $pipelineLabel := .PipelineNames }}
+    <store>
+      @type relabel
+      @label {{labelName $pipelineLabel}}
+    </store>
+{{- end }}
+  </match>
+</label>
+{{- end }}
+{{- end}}`
+
+const inputSelectorBlockTemplate = `{{- define "inputSelectorBlockTemplate" -}}
+    <route>
+      @label {{labelName .Pipeline}}
+      <match>
+{{- if .Namespaces }}
+        namespaces {{ .Namespaces }}
+{{- end}}
+{{- if .Labels }}
+        labels {{ .Labels }}
+{{- end}}
+      </match>
+    </route>
+{{- end}}`
+
 const pipelineToOutputCopyTemplate = `{{- define "pipelineToOutputCopyTemplate" -}}
 <label {{labelName .Name}}>
   {{ if .PipelineLabels -}}
@@ -591,9 +586,21 @@ const pipelineToOutputCopyTemplate = `{{- define "pipelineToOutputCopyTemplate"
     </record>
   </filter>
   {{ end -}}
+  {{ if (eq .Parse "json") -}}
+  <filter **>
+    @type parser
+    key_name message
+    reserve_data yes
+    hash_value_field structured
+    <parse>
+      @type json
+	  json_parser oj
+    </parse>
+  </filter>
+  {{ end -}}
   <match **>
     @type copy
-{{ range $index, $target := .Outputs }}
+{{- range $index, $target := .Outputs }}
     <store>
       @type relabel
       @label {{labelName $target}}
@@ -605,6 +612,33 @@ const pipelineToOutputCopyTemplate = `{{- define "pipelineToOutputCopyTemplate"
 
 const outputLabelConfTemplate = `{{- define "outputLabelConf" -}}
 <label {{.LabelName}}>
+  {{- if (.NeedChangeElasticsearchStructuredType)}}
+  <filter **>
+    @type record_modifier
+	<record>
+	  typeFromKey     ${record.dig({{.GetKeyVal .Target.OutputTypeSpec.Elasticsearch.StructuredTypeKey}})}
+	  hasStructuredTypeName     "{{.Target.OutputTypeSpec.Elasticsearch.StructuredTypeName}}"
+	  viaq_index_name  ${ if !record['structured'].nil? && record['structured'] != {}; if !record['typeFromKey'].nil?; "app-"+record['typeFromKey']+"-write"; elsif record['hasStructuredTypeName'] != ""; "app-"+record['hasStructuredTypeName']+"-write"; else record['viaq_index_name']; end; else record['viaq_index_name']; end;}
+	</record>
+	remove_keys typeFromKey, hasStructuredTypeName
+  </filter>
+  {{- else}}
+  <filter **>
+    @type record_modifier
+	remove_keys structured
+  </filter>
+  {{- end}}
+  {{- if .IsElasticSearchOutput}}
+  #flatten labels to prevent field explosion in ES
+  <filter ** >
+    @type record_transformer
+    enable_ruby true
+    <record>
+      kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
+    </record>
+    remove_keys $.kubernetes.labels
+  </filter>
+  {{- end}}
   <match {{.RetryTag}}>
     @type copy
 {{ include .StoreTemplate . "prefix_as_retry" | indent 4}}
@@ -667,6 +701,7 @@ const forwardTemplate = `{{- define "forward" -}}
 # https://docs.fluentd.org/v1.0/articles/in_forward
 @type forward
 heartbeat_type none
+keepalive true
 {{- with $sharedKey := .GetSecret "shared_key" }}
 <security>
   self_hostname "#{ENV['NODE_NAME']}"
@@ -699,8 +734,16 @@ tls_cert_path "{{$path}}"
   @type file
   path '{{.BufferPath}}'
   queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
+{{- if .TotalLimitSize }}
   total_limit_size {{.TotalLimitSize}}
+{{- else }}
+  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+{{- end }}
+{{- if .ChunkLimitSize }}
   chunk_limit_size {{.ChunkLimitSize}}
+{{- else }}
+  chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
+{{- end }}
   flush_mode {{.FlushMode}}
   flush_interval {{.FlushInterval}}
   flush_at_shutdown true
@@ -768,8 +811,16 @@ const storeElasticsearchTemplate = `{{ define "storeElasticsearch" -}}
     retry_max_interval {{.RetryMaxInterval}}
     retry_forever true
     queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+{{- if .TotalLimitSize }}
     total_limit_size {{.TotalLimitSize}}
+{{- else }}
+    total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+{{- end}}
+{{- if .ChunkLimitSize }}
     chunk_limit_size {{.ChunkLimitSize}}
+{{- else }}
+    chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
+{{- end }}
     overflow_action {{.OverflowAction}}
   </buffer>
 </store>
@@ -844,8 +895,16 @@ const storeSyslogTemplate = `{{- define "storeSyslog" -}}
     retry_max_interval {{.RetryMaxInterval}}
     retry_forever true
     queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+{{- if .TotalLimitSize }}
     total_limit_size {{.TotalLimitSize}}
+{{- else }}
+    total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+{{- end }}
+{{- if .ChunkLimitSize }}
     chunk_limit_size {{.ChunkLimitSize}}
+{{- else }}
+    chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
+{{- end }}
     overflow_action {{.OverflowAction}}
   </buffer>
 </store>
@@ -878,8 +937,16 @@ ssl_client_cert_key "#{File.exist?('{{ $tlsKey }}') ? '{{ $tlsKey }}' : nil}"
   retry_max_interval {{.RetryMaxInterval}}
   retry_forever true
   queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+{{- if .TotalLimitSize }}
   total_limit_size {{.TotalLimitSize}}
+{{- else }}
+  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+{{- end }}
+{{- if .ChunkLimitSize }}
   chunk_limit_size {{.ChunkLimitSize}}
+{{- else }}
+  chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
+{{- end }}
   overflow_action {{.OverflowAction}}
 </buffer>
 {{- end}}
