@@ -13,14 +13,13 @@ import (
 	"github.com/ViaQ/logerr/log"
 	monitoringv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
+	"github.com/openshift/cluster-logging-operator/pkg/components/fluentd"
 	"github.com/openshift/cluster-logging-operator/pkg/constants"
 	"github.com/openshift/cluster-logging-operator/pkg/factory"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
-
 	"github.com/openshift/cluster-logging-operator/pkg/utils/comparators/daemonsets"
 	"github.com/openshift/cluster-logging-operator/pkg/utils/comparators/services"
 	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/intstr"
@@ -284,7 +283,7 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateFluentdConfigMap(flue
 		clusterRequest.Cluster.Namespace,
 		map[string]string{
 			"fluent.conf": fluentConf,
-			"run.sh":      string(utils.GetFileContents(utils.GetShareDir() + "/fluentd/run.sh")),
+			"run.sh":      fluentd.RunScript,
 		},
 	)
 
@@ -374,12 +373,9 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 	if cluster.Spec.Forwarder != nil {
 		if cluster.Spec.Forwarder.Fluentd.Buffer != nil {
 			if cluster.Spec.Forwarder.Fluentd.Buffer.ChunkLimitSize != "" {
-				chunkLimitSize := resource.MustParse(utils.Transform(string(cluster.Spec.Forwarder.Fluentd.Buffer.ChunkLimitSize)))
-				fluentdContainer.Env = append(fluentdContainer.Env, v1.EnvVar{Name: "BUFFER_SIZE_LIMIT", Value: strconv.FormatInt(chunkLimitSize.Value(), 10)})
-			}
-			if cluster.Spec.Forwarder.Fluentd.Buffer.TotalLimitSize != "" {
-				totalLimitSize := resource.MustParse(utils.Transform(string(cluster.Spec.Forwarder.Fluentd.Buffer.TotalLimitSize)))
-				fluentdContainer.Env = append(fluentdContainer.Env, v1.EnvVar{Name: "TOTAL_LIMIT_SIZE_PER_BUFFER", Value: strconv.FormatInt(totalLimitSize.Value(), 10)})
+				if chunkLimitSize, err := utils.ParseQuantity(string(cluster.Spec.Forwarder.Fluentd.Buffer.ChunkLimitSize)); err == nil {
+					fluentdContainer.Env = append(fluentdContainer.Env, v1.EnvVar{Name: "BUFFER_SIZE_LIMIT", Value: strconv.FormatInt(chunkLimitSize.Value(), 10)})
+				}
 			}
 		}
 	}
