@@ -17,7 +17,6 @@ import (
 	"time"
 
 	"github.com/ViaQ/logerr/log"
-
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
 	"github.com/openshift/cluster-logging-operator/pkg/constants"
 	v1 "k8s.io/api/core/v1"
@@ -34,7 +33,7 @@ const (
 // COMPONENT_IMAGES are thee keys are based on the "container name" + "-{image,version}"
 var COMPONENT_IMAGES = map[string]string{
 	"curator":             "CURATOR_IMAGE",
-	constants.FluentdName: "FLUENTD_IMAGE",
+	constants.FluentdName: constants.FluentdImageEnvVar,
 	"kibana":              "KIBANA_IMAGE",
 }
 
@@ -443,11 +442,6 @@ func WrapError(err error) error {
 	return err
 }
 
-// Transforming input value to binary notation
-func Transform(value string) string {
-	if !strings.HasSuffix(value, "i") {
-		value = strings.ToUpper(value)
-		value += "i"
-	}
-	return value
+func ToJsonLogs(logs []string) string {
+	return fmt.Sprintf("[%s]", strings.Join(logs, ","))
 }
